summaryrefslogtreecommitdiff
path: root/usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c
diff options
context:
space:
mode:
authorJanie Lu <Janie.Lu@Sun.COM>2009-12-11 10:41:17 -0800
committerJanie Lu <Janie.Lu@Sun.COM>2009-12-11 10:41:17 -0800
commit4df55fde49134f9735f84011f23a767c75e393c7 (patch)
treec931c232038f950125a092f71e687cd653485b16 /usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c
parent93fcb0b9b3e0792a42d10584632c1c566f89d64a (diff)
downloadillumos-joyent-4df55fde49134f9735f84011f23a767c75e393c7.tar.gz
FWARC 2008/613 KT IOS Performance Counters API
FWARC 2008/615 KT Perf Reg HV API FWARC 2009/434 KT IOS Performance Counters API Update FWARC 2009/567 Parallel Boot HV APIs PSARC 2009/177 Solaris support for Rainbow Falls platforms PSARC 2009/389 Sun4v faulted SP events extension PSARC 2009/533 CRYPTO_HMAC_NO_UPDATE - A new KCF SPI flag PSARC 2009/605 more sun4v platform-independent cpu/mem FMA events PSARC 2009/649 Generic PCIe root complex FMA events 6704999 extend xaui enum to work in platform independent world 6773223 RFE: guest epkt for faulted SP 6773225 RFE: Diagnosis of a faulted SP 6797776 Solaris support for Rainbow Falls platforms
Diffstat (limited to 'usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c')
-rw-r--r--usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c10
1 files changed, 4 insertions, 6 deletions
diff --git a/usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c b/usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c
index 67967bb223..54a544d683 100644
--- a/usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c
+++ b/usr/src/lib/pkcs11/pkcs11_kernel/common/kernelSession.c
@@ -19,12 +19,10 @@
* CDDL HEADER END
*/
/*
- * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
-#pragma ident "%Z%%M% %I% %E% SMI"
-
#include <pthread.h>
#include <errno.h>
#include <security/cryptoki.h>
@@ -244,8 +242,8 @@ kernel_get_operationstate(kernel_session_t *session_p, CK_STATE ses_state,
/*
* XXX Need to support this case in future.
* This is the case where we exceeded SLOT_MAX_INDATA_LEN and
* hence started using libmd. SLOT_MAX_INDATA_LEN is at least
* 64K for current crypto framework providers and web servers
* do not need to clone digests that big for SSL operations.
*/
@@ -369,7 +367,7 @@ kernel_set_operationstate(kernel_session_t *session_p, CK_STATE ses_state,
/* compute the data buffer length */
indata_len = expected_len - sizeof (int) -
sizeof (CK_STATE) - sizeof (crypto_active_op_t);
- if (indata_len > SLOT_MAX_INDATA_LEN(session_p))
+ if (indata_len > SLOT_HASH_MAX_INDATA_LEN(session_p))
return (CKR_SAVED_STATE_INVALID);
src += sizeof (int);
@@ -244,8 +242,8 @@ kernel_get_operationstate(kernel_session_t *session_p, CK_STATE ses_state,
/*
* XXX Need to support this case in future.
- * This is the case where we exceeded SLOT_MAX_INDATA_LEN and
- * hence started using libmd. SLOT_MAX_INDATA_LEN is at least
+ * This is the case where we exceeded SLOT_HASH_MAX_INDATA_LEN and
+ * hence started using libmd. SLOT_HASH_MAX_INDATA_LEN is at least
* 64K for current crypto framework providers and web servers
* do not need to clone digests that big for SSL operations.